@@ -2,7 +2,7 @@
 import time
 
 import musicbrainzngs
-from musicbrainzngs import compat
+from os.path import join
 
 try:
     from urllib2 import OpenerDirector
@@ -15,20 +15,23 @@ except ImportError:
 
 class FakeOpener(OpenerDirector):
     """ A URL Opener that saves the URL requested and
-    returns a dummy response """
-    def __init__(self):
+    returns a dummy response or raises an exception """
+    def __init__(self, response="<response/>", exception=None):
         self.myurl = None
+        self.response = response
+        self.exception = exception
 
     def open(self, request, body=None):
         self.myurl = request.get_full_url()
         self.request = request
-        return StringIO.StringIO("<response/>")
+        if self.exception:
+            raise self.exception
+        else:
+            return StringIO.StringIO(self.response)
 
     def get_url(self):
         return self.myurl
 
-opener = FakeOpener()
-musicbrainzngs.compat.build_opener = lambda *args: opener
 
 # Mock timing.
 class Timecop(object):
@@ -55,3 +58,16 @@ class Timecop(object):
     def restore(self):
         time.time = self.orig['time']
         time.sleep = self.orig['sleep']
+
+def open_and_parse_test_data(datadir, filename):
+    """ Opens an XML file dumped from the MusicBrainz web service and returns
+    the parses it.
+
+    :datadir: The directory containing the file
+    :filename: The filename of the XML file
+    :returns: The parsed representation of the XML files content
+
+    """
+    fn = join(datadir, filename)
+    res = musicbrainzngs.mbxml.parse_message(open(fn))
+    return res
